@@ -20,17 +20,13 @@ from torchdatasetutil.imstore import ImagesStore
 test_config = 'test.yaml'
 class Test(unittest.TestCase):      
 
-    '''def test_iterator(self):
+    def test_iterator(self):
         parameters = ReadDict(test_config)
 
         if 'images' not in parameters:
             raise ValueError('images not in {}'.format(test_config))
 
         s3, creds, s3def = Connect(parameters['images']['credentials'])
-
-        #dataset_desc = s3.GetDict(s3def['sets']['dataset']['bucket'],parameters['images']['dataset'])
-        #class_dictionary = s3.GetDict(s3def['sets']['dataset']['bucket'],parameters['images']['class_dict']) 
-        #imUtil = ImUtil(dataset_desc, class_dictionary)
                 
         store = ImagesStore(s3, bucket=s3def['sets']['dataset']['bucket'], 
                         dataset_desc=parameters['images']['dataset'], 
@@ -40,12 +36,9 @@ class Test(unittest.TestCase):
             img = store.MergeIman(iman['img'], iman['ann'])
             if img is None:
                 raise ValueError('img is None')
-            if 'test_images' in parameters['coco'] and i >= parameters['coco']['test_images']:
-                break'''
+            if 'test_images' in parameters['images'] and i >= parameters['images']['test_images']:
+                break
     
-
-
-
     def test_dataset(self):
         print('test_dataset: create me!')
 
